

/*
 Codes for "International Lending: The Role of Lender's Home Country"
 The main datasets used to generate tables in the paper include:
	- Loan Pricing Corporation's DealScan loan data (snapshot 2017)
	- WorldScope firm level financial data
	- JPE paper (Debt Enforcement Around the World by Djankov et al. (2007) )
 The first two datasets are vendor data and need to be purchased by the user. The third data is avaiable at https://scholar.harvard.edu/shleifer/publications?page=3 

 We have merged DealScan with WorldScope. The ID-matches originally created for this paper are made publicly avaiable by WRDS and are being updated regularly. 
 link: https://wrds-web.wharton.upenn.edu/wrds/ds/wrdsapps/link/dswslink/index.cfm?navId=539
 The user needs to cite this paper.

 In the following codes to run all the regressions in the paper are provided. The variable neames are self-explanatory.
*/


use "..\jmcbPaper_data.dta"

global lender01 "l_creditor_rights l_fren l_ger l_scan"
global lender02 "l_creditor_rights_augmented l_fren l_ger l_scan"
global lender03 "l_lncdays l_fren l_ger l_scan"
global lender04 "l_creditor_rights l_property_rights l_fren l_ger l_scan"
global lender05 "l_creditor_rights l_political_risk l_financial_risk l_fren l_ger l_scan"
global lender06 "l_creditor_rights l_corruption l_fren l_ger l_scan"
global lender07 "l_credi_diff_pos l_credi_diff_neg l_fren l_ger l_scan"
global lender08 "l_cred_diff l_fren l_ger l_scan"
global lender09 "l_time_diff_pos l_time_diff_neg l_fren l_ger l_scan"
global lender10 "l_lncdays l_property_rights l_fren l_ger l_scan"
global lender11 "change_l_cr l_fren l_ger l_scan"


global borrower01 "b_creditor_rights b_fren b_ger b_scan"
global borrower02 "b_creditor_rights_augmented b_fren b_ger b_scan"
global borrower03 "b_lncdays b_fren b_ger b_scan"
global borrower04 "b_creditor_rights b_property_rights b_fren b_ger b_scan"
global borrower05 "b_creditor_rights b_political_risk b_financial_risk b_fren b_ger b_scan"
global borrower06 "b_creditor_rights b_corruption b_fren b_ger b_scan"
global borrower08 "b_credi_diff_pos b_credi_diff_neg b_corruption b_fren b_ger b_scan"
global borrower09 "b_lncdays b_property_rights b_fren b_ger b_scan"
global borrower10 "change_b_cr b_fren b_ger b_scan"

global firm "log_assets profitability_win leverage_win tangibility_win mb_ratio_win"
global distance01 "log_distcap contig prior_relationship"
global purpose "corp_purposes work_cap debt_repay lbo_manda project_finance capex cp_backup recap debtor_in_poss"
global controls "revolver b_gdp_growth_prc l_gdp_growth_prc sic_1digit* year1* year2*"

count



************************************************************************************************************************************************
* Table 1-4 are done in SAS (Sum stat). I replicate the last two columns of Table 4 here (main regressions)
************************************************************************************************************************************************
* Columns (7) and (8) of Table 4
regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table3, replace excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)
regress log_allindrawn $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table3, append excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, No) dec(3)

************************************************************************************************************************************************
* Table 3: New sum stat table (average spread, maturity, amount) based on borrower and lender creditor rights
* editor suggested normalizing amount first
	gen amt_w = facilityamt_usd
	winsor2 amt_w, replace cuts(1 99)
	tabout b_creditor_rights l_creditor_rights using Table2referee.xls , c(mean allindrawn_w ) f(3) sum h3(nil) ptotal(none) replace
	tabout b_creditor_rights l_creditor_rights using Table2referee.xls , c(mean facilitymaturity ) f(3) sum h3(nil) ptotal(none)  append
	tabout b_creditor_rights l_creditor_rights using Table2referee.xls , c(mean amt_w) f(0c) sum h3(nil) ptotal(none)  append


************************************************************************************************************************************************


* Table 5
* Asymmetric effect
gen l_cred_diff = l_creditor_rights - b_creditor_rights
gen l_credi_diff_pos = abs(l_cred_diff) if l_cred_diff>0 & !missing(l_cred_diff)
replace l_credi_diff_pos = 0 if l_cred_diff<=0 & !missing(l_cred_diff)
gen l_credi_diff_neg = abs(l_cred_diff) if l_cred_diff<0 & !missing(l_cred_diff)
replace l_credi_diff_neg = 0 if l_cred_diff>=0 & !missing(l_cred_diff)

* spread
regress log_allindrawn $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, replace excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
regress log_allindrawn $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, append excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

* maturity
regress log_maturity $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
regress log_maturity $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

* amount
regress log_loan_size_usd $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
regress log_loan_size_usd $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

************************************************************************************************************************************************
	* Additional test in response to referee B's report (are lenders from good CR pick low risk borrowers, that is why their spreads are lower?)
		gen lender_crhigh=1 if l_creditor_rights>2
			replace lender_crhigh=0 if missing(lender_crhigh)
		* country and year fixed effexts
		egen bcountry = group(b_country)
		egen y = group(year)
			* 2 regressions: explaining good lender creditor rights as a function of firm characteristics with and witout country fixed effects;
			regress lender_crhigh $firm, vce(cluster b_country)
			outreg2 using Table5referee, replace excel ctitle(Lender from good CR country=1) keep($firm) addtext(Borrower country fixed effects, No) dec(3)
			reghdfe lender_crhigh $firm, absorb(bcountry) vce(cluster b_country)
			outreg2 using Table5referee, append excel ctitle(Lender from good CR country=1) keep($firm) addtext(Borrower country fixed effects, Yes) dec(3)
			
		* Additional test in response to referee's report (No US lender and Weights by reverse number of lender country)
			* spread
				regress log_allindrawn $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
				outreg2 using Table5referee2, replace excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* no US lender
				regress log_allindrawn $lender07 $borrower01 $firm $distance01 $purpose $controls if l_country !="USA", vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* weighted least squares whereby the weights are the inverse of the number of loans per lender country
				regress log_allindrawn $lender07 $borrower01 $firm $distance01 $purpose $controls [w=weight_lcountryfirm] , vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* maturity
				regress log_maturity $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* no US lender
				regress log_maturity $lender07 $borrower01 $firm $distance01 $purpose $controls if l_country !="USA", vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* weighted least squares whereby the weights are the inverse of the number of loans per lender country
				regress log_maturity $lender07 $borrower01 $firm $distance01 $purpose $controls [w=weight_lcountryfirm] , vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* amount
				regress log_loan_size_usd $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* no US lender
				regress log_loan_size_usd $lender07 $borrower01 $firm $distance01 $purpose $controls if l_country !="USA", vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
				* weighted least squares whereby the weights are the inverse of the number of loans per lender country
				regress log_loan_size_usd $lender07 $borrower01 $firm $distance01 $purpose $controls [w=weight_lcountryfirm] , vce(cluster b_country)
				outreg2 using Table5referee2, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

		* Additional test in response to referee's report (Separating based on the level of borrower creditor rights)
		gen lcr_b0 = l_creditor_rights*(b_creditor_rights==0)
		gen lcr_b1 = l_creditor_rights*(b_creditor_rights==1)
		gen lcr_b2 = l_creditor_rights*(b_creditor_rights==2)
		gen lcr_b3 = l_creditor_rights*(b_creditor_rights==3)
		gen lcr_b4 = l_creditor_rights*(b_creditor_rights==4)
			* spread:
			regress log_allindrawn b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, replace excel ctitle(Spread) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_allindrawn b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, append excel ctitle(Spread) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* maturity:
			regress log_maturity b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, append excel ctitle(Maturity) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_maturity b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, append excel ctitle(Maturity) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* amount:
			regress log_loan_size_usd b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, append excel ctitle(Amount) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_loan_size_usd b_creditor_rights lcr_b0 lcr_b1 lcr_b2 lcr_b3 l_fren l_ger l_scan b_fren b_ger b_scan $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee3, append excel ctitle(Amount) keep(lcr_b0 lcr_b1 lcr_b2 lcr_b3 b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

		* Additional test in response to referee's report (borrower minus lender, not the other way around)
		gen b_cred_diff = b_creditor_rights - l_creditor_rights
		gen b_credi_diff_pos = abs(b_cred_diff) if b_cred_diff>0 & !missing(b_cred_diff)
		replace b_credi_diff_pos = 0 if b_cred_diff<=0 & !missing(b_cred_diff)
		gen b_credi_diff_neg = abs(b_cred_diff) if b_cred_diff<0 & !missing(b_cred_diff)
		replace b_credi_diff_neg = 0 if b_cred_diff>=0 & !missing(b_cred_diff)

			* spread
			regress log_allindrawn $borrower08 $lender01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, replace excel ctitle(Spread) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_allindrawn $borrower08 $lender01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, append excel ctitle(Spread) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* maturity
			regress log_maturity $borrower08 $lender01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, append excel ctitle(Maturity) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_maturity $borrower08 $lender01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, append excel ctitle(Maturity) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* amount
			regress log_loan_size_usd $borrower08 $lender01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, append excel ctitle(Amount) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_loan_size_usd $borrower08 $lender01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee4, append excel ctitle(Amount) keep(b_credi_diff_pos b_credi_diff_neg l_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

		* Additional test in response to referee's report (do not separate the differences. Just use one difference)
			
			* spread
			regress log_allindrawn $lender08 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, replace excel ctitle(Spread) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_allindrawn $lender08 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, append excel ctitle(Spread) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

			* maturity
			regress log_maturity $lender08 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, append excel ctitle(Maturity) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_maturity $lender08 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, append excel ctitle(Maturity) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

			* amount
			regress log_loan_size_usd $lender08 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, append excel ctitle(Amount) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_loan_size_usd $lender08 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
			outreg2 using Table5referee5, append excel ctitle(Amount) keep(l_cred_diff b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)

		* Additional test in response to referee's report (clustering at lender countries)
			* spread
			regress log_allindrawn $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, replace excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_allindrawn $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, append excel ctitle(Spread) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* maturity
			regress log_maturity $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_maturity $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, append excel ctitle(Maturity) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
			* amount
			regress log_loan_size_usd $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
			regress log_loan_size_usd $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster l_country)
			outreg2 using Table5referee6, append excel ctitle(Amount) keep(l_credi_diff_pos l_credi_diff_neg b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)



************************************************************************************************************************************************
* Table 6
* Spread

* augmented creditor rights
regress log_allindrawn $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table6, replace excel ctitle(Spread) keep(l_creditor_rights b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table6, append excel ctitle(Spread) keep(l_creditor_rights b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
* <= 2003
regress log_allindrawn $lender01 $borrower01 $distance01 $purpose $controls if year <= 2003, vce(cluster b_country)
outreg2 using Table6, append excel ctitle(Spread) keep(l_creditor_rights b_creditor_rights) addtext(Control for borrower characteristics, No) dec(3)
regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls if year <= 2003, vce(cluster b_country)
outreg2 using Table6, append excel ctitle(Spread) keep(l_creditor_rights b_creditor_rights) addtext(Control for borrower characteristics, Yes) dec(3)
* time to enforce contracts
regress log_allindrawn $lender03 $borrower03 $distance01 $purpose $controls , vce(cluster b_country)
outreg2 using Table6, append excel ctitle(Spread) keep(l_lncdays b_lncdays) addtext(Control for borrower characteristics, No) dec(3)
regress log_allindrawn $lender03 $borrower03 $firm $distance01 $purpose $controls , vce(cluster b_country)
outreg2 using Table6, append excel ctitle(Spread) keep(l_lncdays b_lncdays) addtext(Control for borrower characteristics, Yes) dec(3)

	

************************************************************************************************************************************************
* Table 7
* property rights
* Spread
regress log_allindrawn $lender04 $borrower04 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table7, replace excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table7, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)

		* Referee A version (time to enforce instead of creditor rights)
		regress log_allindrawn $lender09 $borrower09 $distance01 $purpose $controls, vce(cluster b_country)
		regress log_allindrawn $lender09 $borrower09 $firm $distance01 $purpose $controls, vce(cluster b_country)


************************************************************************************************************************************************
* Table 8
* Other legal environment indicators
* Spread
* financial and political
regress log_allindrawn $lender05 $borrower05 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table8, replace excel ctitle(Spread) keep(l_creditor_rights l_political_risk l_financial_risk b_creditor_rights b_political_risk b_financial_risk) dec(3)
regress log_allindrawn $lender05 $borrower05 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table8, append excel ctitle(Spread) keep(l_creditor_rights l_political_risk l_financial_risk b_creditor_rights b_political_risk b_financial_risk) dec(3)
* corruption
regress log_allindrawn $lender06 $borrower06 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table8, append excel ctitle(Spread) keep(l_creditor_rights l_corruption b_creditor_rights b_corruption) dec(3)
regress log_allindrawn $lender06 $borrower06 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table8, append excel ctitle(Spread) keep(l_creditor_rights l_corruption b_creditor_rights b_corruption) dec(3)

************************************************************************************************************************************************
* Table 9
* guarantor
* Spread
regress log_allindrawn $lender04 $borrower04 $distance01 has_guarantor $purpose $controls, vce(cluster b_country)
outreg2 using Table9, replace excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_guarantor) dec(3)
regress log_allindrawn $lender04 $borrower04 $distance01 has_guarantor g_in_l_country_atlest $purpose $controls, vce(cluster b_country)
outreg2 using Table9, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_guarantor g_in_l_country_atlest) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 has_guarantor $purpose $controls, vce(cluster b_country)
outreg2 using Table9, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_guarantor) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 has_guarantor g_in_l_country_atlest $purpose $controls, vce(cluster b_country)
outreg2 using Table9, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_guarantor g_in_l_country_atlest) dec(3)


************************************************************************************************************************************************
* Table 10
* freign assets
gen foreign_assets_in_lender= l_creditor_rights* foreign_assets_in_l_atlest

* Spread
regress log_allindrawn $lender04 $borrower04 $distance01 has_foreign_assets $purpose $controls, vce(cluster b_country)
outreg2 using Table10, replace excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets) dec(3)
regress log_allindrawn $lender04 $borrower04 $distance01 has_foreign_assets foreign_assets_in_l_atlest $purpose $controls, vce(cluster b_country)
outreg2 using Table10, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets foreign_assets_in_l_atlest) dec(3)
regress log_allindrawn $lender04 $borrower04 $distance01 has_foreign_assets foreign_assets_in_l_atlest foreign_assets_in_lender $purpose $controls, vce(cluster b_country)
outreg2 using Table10, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets foreign_assets_in_l_atlest foreign_assets_in_lender) dec(3)

regress log_allindrawn $lender04 $borrower04 $firm $distance01 has_foreign_assets  $purpose $controls, vce(cluster b_country)
outreg2 using Table10, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 has_foreign_assets foreign_assets_in_l_atlest $purpose $controls, vce(cluster b_country)
outreg2 using Table10, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets foreign_assets_in_l_atlest) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 has_foreign_assets foreign_assets_in_l_atlest foreign_assets_in_lender $purpose $controls, vce(cluster b_country)
outreg2 using Table10, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights has_foreign_assets foreign_assets_in_l_atlest foreign_assets_in_lender) dec(3)


************************************************************************************************************************************************
* Table 11
* Spread
* secure
regress log_allindrawn $lender04 $borrower04 $distance01 $purpose $controls if secure==1, vce(cluster b_country)
outreg2 using Table11, replace excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 $purpose $controls if secure==1, vce(cluster b_country)
outreg2 using Table11, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)
* unsecured
regress log_allindrawn $lender04 $borrower04 $distance01 $purpose $controls if secure==0, vce(cluster b_country)
outreg2 using Table11, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)
regress log_allindrawn $lender04 $borrower04 $firm $distance01 $purpose $controls if secure==0, vce(cluster b_country)
outreg2 using Table11, append excel ctitle(Spread) keep(l_creditor_rights l_property_rights b_creditor_rights b_property_rights) dec(3)

************************************************************************************************************************************************
* Table 12 (Use Time to Enforce Contracts Index instead of CR Index)
* Asymmetric effect using Time to Enforce Index
gen l_time_diff = l_lncdays - b_lncdays
gen l_time_diff_pos = abs(l_time_diff) if l_time_diff>0 & !missing(l_time_diff)
replace l_time_diff_pos = 0 if l_time_diff<=0 & !missing(l_time_diff)
gen l_time_diff_neg = abs(l_time_diff) if l_time_diff<0 & !missing(l_time_diff)
replace l_time_diff_neg = 0 if l_time_diff>=0 & !missing(l_time_diff)

* main regression
regress log_allindrawn $lender03 $borrower03 $distance01 $purpose $controls , vce(cluster b_country)
outreg2 using Table5refereeA, replace excel ctitle(Spread) keep(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) sortvar(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) addtext(Control for borrower characteristics, No) dec(3)
* difference
regress log_allindrawn $lender09 $borrower03 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5refereeA, append excel ctitle(Spread) keep(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) sortvar(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) addtext(Control for borrower characteristics, No) dec(3)
* with property rights
regress log_allindrawn $lender10 $borrower09 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using Table5refereeA, append excel ctitle(Spread) keep(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) sortvar(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) dec(3)
* secured
regress log_allindrawn $lender10 $borrower09 $distance01 $purpose $controls if secure==1, vce(cluster b_country)
outreg2 using Table5refereeA, append excel ctitle(Spread) keep(l_lncdays  l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) sortvar(l_lncdays l_time_diff_neg l_time_diff_pos l_property_rights b_lncdays b_property_rights has_guarantor g_in_l_country_atlest) dec(3)

		
************************************************************************************************************************************************
* Appendix

* Appropriateness of instruments
regress log_allindrawn colony comlang_off lender_prc_share_in_country $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
test (colony=0) (comlang_off=0) (lender_prc_share_in_country=0)

regress log_allindrawn comlang_off  $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)

regress log_allindrawn colony $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)

regress log_allindrawn lender_prc_share_in_country $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)

regress log_maturity colony comlang_off lender_prc_share_in_country $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
test (colony=0) (comlang_off=0) (lender_prc_share_in_country=0)

regress log_loan_size_usd colony comlang_off lender_prc_share_in_country $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
test (colony=0) (comlang_off=0) (lender_prc_share_in_country=0)

************************************************************************************************************************************************
* Cov (missing for many observatins)
regress no_fcov $lender01 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using TableCov, replace excel ctitle(Covenant) keep(l_creditor_rights  $lender07 $borrower01 $distance01) addtext(Control for borrower characteristics, No) dec(3)
regress no_fcov $lender01 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using TableCov, append excel ctitle(Covenant) keep(l_creditor_rights  $lender07 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)
regress no_fcov $lender07 $borrower01 $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using TableCov, append excel ctitle(Covenant) keep(l_creditor_rights  $lender07 $borrower01 $distance01) addtext(Control for borrower characteristics, No) dec(3)
regress no_fcov $lender07 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
outreg2 using TableCov, append excel ctitle(Covenant) keep(l_creditor_rights  $lender07 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)

gen log_nlender = log(n_of_lenders+1)

* using syndicate structure as controls
gen n_of_lenders_adj=n_of_lenders
replace n_of_lenders_adj=1 if missing(n_of_lenders_adj)
gen log_nlenders = log(n_of_lenders_adj+1)

regress log_allindrawn $lender01 $borrower01 $distance01 $purpose deal_with_institutional  $controls, vce(cluster b_country)
outreg2 using TableA, append excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, No) dec(3)

regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose deal_with_institutional n_of_lenders_adj $controls, vce(cluster b_country)
outreg2 using TableA, replace excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)


save "__temp", replace



************************************************************************************************************************************************
* Additional test in response to referee's report and editor's comment ((i) drop all US deals(ii) weighted least squares)
	* creating weights as the number of loans per lender country
	sort l_country
	egen N_lendercountry = count(lendercompanyid), by (l_country)
	gen weight_lcountry = 1/N_lendercountry 
		replace weight_lcountry=. if weight_lcountry==1
	* same thing, but conditioning on firm characteristics exist	
	egen N_lendercountryfirm = count(lendercompanyid) if ~missing(log_assets), by (l_country)
	gen weight_lcountryfirm = 1/N_lendercountryfirm
		replace weight_lcountryfirm=. if weight_lcountryfirm==1
	
	* original
	regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls, vce(cluster b_country)
	outreg2 using Table3referee, replace excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)
	* no US lender
	regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls if l_country !="USA", vce(cluster b_country)
	outreg2 using Table3referee, append excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)
	* weighted least squares whereby the weights are the inverse of the number of loans per lender country
	regress log_allindrawn $lender01 $borrower01 $firm $distance01 $purpose $controls [w=weight_lcountryfirm], vce(cluster b_country)
	outreg2 using Table3referee, append excel ctitle(Spread) keep($lender01 $borrower01 $distance01) addtext(Control for borrower characteristics, Yes) dec(3)
	
